package com.gic.haoban.manage.web.controller;

import java.io.IOException;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.hutool.core.collection.CollectionUtil;

import com.gic.api.base.commons.Page;
import com.gic.commons.util.GlobalVar;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.service.StoreService;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.base.api.common.PageResult;
import com.gic.haoban.common.utils.EntityUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.dto.EnterpriseDetailDTO;
import com.gic.haoban.manage.api.dto.YwWxEnterpriseDTO;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseRelatedApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.vo.EnterpriseDetailVo;

@RestController
public class EnterpriseController extends WebBaseController{
    private static final String LOGIN_URL = "/haoban-manage3-web/yw-login";
	private static Logger logger  = LoggerFactory.getLogger(EnterpriseController.class);

	@Autowired
	private WxEnterpriseApiService wxEnterpriseApiService;
	@Autowired
	private WxEnterpriseRelatedApiService wxEnterpriseRelatedApiService;
	@Autowired
	private DepartmentApiService departmentApiService;
	@Autowired
	private StoreService storeService;
	//企业列表
	@RequestMapping("wx-enterprise-list")
	public HaobanResponse wxEnterpriseList(BasePageInfo pageInfo,String keyword,Integer gicContactHelper,String version) {
		Page<YwWxEnterpriseDTO> page = wxEnterpriseApiService.list(pageInfo,keyword,gicContactHelper,version);
		PageResult<YwWxEnterpriseDTO> pageVo = new PageResult<>();
		List<YwWxEnterpriseDTO> list = EntityUtil.changeEntityListByJSON(YwWxEnterpriseDTO.class, page.getResult());
		for(YwWxEnterpriseDTO dto : list){
			dto.setVersion("3.0");
			dto.setBuyDate(new Date());
			dto.setBuyStatus("1");
			List<EnterpriseDetailDTO> counts = wxEnterpriseRelatedApiService.listEnterpriseByWxEnterpriseId(dto.getWxEnterpriseId());
			dto.setRelationCount(counts.size());
		}
		pageVo.setList(list);
        pageVo.setPageNum(page.getCurrentPage());
        pageVo.setPages(page.getPages());
        pageVo.setPageSize(page.getPageSize());
        pageVo.setTotal(page.getTotalCount());
		return resultResponse(HaoBanErrCode.ERR_1,pageVo);
 
	}
	//授权详情列表
	@RequestMapping("authorize-detail")
	public HaobanResponse authorizeDetail(String wxEnterpriseId) {
		List<EnterpriseDetailDTO>  list = wxEnterpriseRelatedApiService.listEnterpriseByWxEnterpriseId(wxEnterpriseId);
		List<EnterpriseDetailVo> result = EntityUtil.changeEntityListByJSON(EnterpriseDetailVo.class, list);
		for(EnterpriseDetailVo vo:result){
			List<StoreDTO>  stores = storeService.getStoreByEnterId(vo.getEnterpriseId(), null, null);
			if(CollectionUtil.isEmpty(stores)){
				continue;
			}else{
				List<String> storeIds = stores.stream().map(s->s.getStoreId()).collect(Collectors.toList());
				List<DepartmentDTO> countList = departmentApiService.listByRelatedIds(storeIds);
				vo.setStoreCount(countList.size());
			}
			
		}
		return resultResponse(HaoBanErrCode.ERR_1,result);
	}
	
	//登录
	@RequestMapping("yw-login")
	public void ywLogin(String wxEnterpriseId,HttpServletResponse httpServletResponse) throws IOException {
        String host = GlobalVar.ctxPropertiesMap.get("haoban_service_host");
        logger.info("host============================>{}",host);
        String url=host+LOGIN_URL+"?wxEnterpriseId="+wxEnterpriseId;
        httpServletResponse.sendRedirect(url);
	}
}
