package com.gic.haoban.manage.web.controller;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collector;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.hutool.core.collection.CollectionUtil;

import com.alibaba.druid.util.StringUtils;
import com.gic.api.base.commons.Page;
import com.gic.enterprise.api.dto.EnterpriseAndUserDTO;
import com.gic.enterprise.api.dto.EnterpriseDTO;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.dto.StoreSearchDTO;
import com.gic.enterprise.api.service.EnterpriseService;
import com.gic.enterprise.api.service.StoreService;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.common.utils.EntityUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.dto.EnterpriseDetailDTO;
import com.gic.haoban.manage.api.dto.WxEnterpriseDTO;
import com.gic.haoban.manage.api.dto.YwWxEnterpriseDTO;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseRelatedApiService;
import com.gic.haoban.manage.web.anno.HttpLimit;
import com.gic.haoban.manage.web.anno.IgnoreLogin;
import com.gic.haoban.manage.web.auth.AuthRequestUtil;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.vo.LoginVO;
import com.gic.haoban.manage.web.vo.StoreVo;

@RestController
public class WxEnterpriseController extends WebBaseController{
	@Autowired
	private WxEnterpriseRelatedApiService wxEnterpriseRelatedApiService;
	@Autowired
	private EnterpriseService enterpriseService;
	@Autowired
	private WxEnterpriseApiService wxEnterpriseApiService;
	@Autowired
	private DepartmentApiService departmentApiService;
	@Autowired
	private StoreService storeService;
	
	//授权企业列表
	@HttpLimit
	@IgnoreLogin
	@RequestMapping("wx-enterprise-list")
	public HaobanResponse wxEnterpriseList() {
//		String wxEnterpriseId = "123456";
		LoginVO login = (LoginVO) AuthRequestUtil.getSessionUser();
		String wxEnterpriseId = login.getWxEnterpriseId();
		List<EnterpriseDetailDTO> list = wxEnterpriseRelatedApiService.listEnterpriseByWxEnterpriseId(wxEnterpriseId);
		if(CollectionUtil.isNotEmpty(list)){
			List<String> enterpriseIds = list.stream().map(s->s.getEnterpriseId()).collect(Collectors.toList());
			List<EnterpriseDTO> enterpriseList = enterpriseService.listEnterpriseByIds(enterpriseIds);
			Map<String,EnterpriseDTO> map = com.gic.commons.util.CollectionUtil.toMap(enterpriseList, "enterpriseId");
			for(EnterpriseDetailDTO dto:list){
				EnterpriseDTO enterpriseDTO = map.get(dto.getEnterpriseId());
				if(enterpriseDTO!=null){
					dto.setEnterpriseName(enterpriseDTO.getEnterpriseName());
					dto.setEnterpriseLogo(enterpriseDTO.getImageUrl());
				}
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1, list);
 
	}
	
	//企业信息
	@IgnoreLogin
	@RequestMapping("wxEnterprise-detail")
	public HaobanResponse enterpriseDetail(String wxEnterpriseId) {
		if(StringUtils.isEmpty(wxEnterpriseId)){
			return resultResponse(HaoBanErrCode.ERR_1);
		}
		WxEnterpriseDTO wxEnterpriseDTO = wxEnterpriseApiService.getOne(wxEnterpriseId);
		return resultResponse(HaoBanErrCode.ERR_1,wxEnterpriseDTO);
	}
	//gic企业列表
	@IgnoreLogin
	@RequestMapping("enterprise-search")
	public HaobanResponse gicEnterpriseDetail(String enterpriseName) {
		if(StringUtils.isEmpty(enterpriseName)){
			return resultResponse(HaoBanErrCode.ERR_1);
		}
		EnterpriseAndUserDTO dto = enterpriseService.getEnterpriseAndUserByName(enterpriseName);
		return resultResponse(HaoBanErrCode.ERR_1,dto);
 
	}
	//微信企业绑定接口
	@IgnoreLogin
	@RequestMapping("wx-enterprise-bind")
	public HaobanResponse wxEnterpriseBind(String enterpriseId,String wxEnterpriseId,String version) {
		if(org.apache.commons.lang3.StringUtils.isAnyBlank(enterpriseId,version)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		LoginVO login = (LoginVO) AuthRequestUtil.getSessionUser();
		wxEnterpriseId = login.getWxEnterpriseId();
		int i = wxEnterpriseRelatedApiService.wxEnterpriseBind(enterpriseId,wxEnterpriseId,version);
		if(i==1){
			return resultResponse(HaoBanErrCode.ERR_10006);
		}
		return resultResponse(HaoBanErrCode.ERR_1);
 
	}
	//溢出门店列表
	@IgnoreLogin
	@RequestMapping("store-full-list")
	public HaobanResponse storeFullList(BasePageInfo basePageInfo,String keyWord) {
		LoginVO login = (LoginVO) AuthRequestUtil.getSessionUser();
		String wxEnterpriseId = login.getWxEnterpriseId();
//		String wxEnterpriseId = "1";
		int maxVersionCount = 0;
		List<EnterpriseDetailDTO>  enterpriseList = wxEnterpriseRelatedApiService.listEnterpriseByWxEnterpriseId(wxEnterpriseId);
		if(CollectionUtil.isEmpty(enterpriseList)){
			return resultResponse(HaoBanErrCode.ERR_10010);
		}
		List<String> enterpriseIds = enterpriseList.stream().map(s->s.getEnterpriseId()).collect(Collectors.toList());
		//获取门店列表
		Page page1 = new Page<>();
		page1.setCurrentPage(1);
		page1.setPageSize(Integer.MAX_VALUE);
		StoreSearchDTO storeSearchDTO = new StoreSearchDTO();
		storeSearchDTO.setEnterpriseIdList(enterpriseIds);
		storeSearchDTO.setSearchName(keyWord);
		Page storePage = storeService.storeListPage(page1, storeSearchDTO);
		if(storePage == null || storePage.getResult()==null){
			return resultResponse(HaoBanErrCode.ERR_10009);
		}
		List<StoreDTO> t_list = storePage.getResult();
		List<String> storeIds = t_list.stream().map(s->s.getStoreId()).collect(Collectors.toList());
		if(StringUtils.isEmpty(keyWord)){
			storeIds = null;
		}
		Page<DepartmentDTO> page = departmentApiService.pageFullStoreByWxEnterpriseId(wxEnterpriseId, keyWord,storeIds,maxVersionCount, basePageInfo);
		List<DepartmentDTO> list = page.getResult();
		List<StoreVo> resultList = EntityUtil.changeEntityListByJSON(StoreVo.class,list);
		
		
		
		List<String> t_storeIds = list.stream().map(s->s.getRelatedId()).collect(Collectors.toList());
		String [] storeIdArr =  t_storeIds.toArray(new String[t_storeIds.size()]);
		List<StoreDTO> storeList = storeService.getStores(storeIdArr);
		Map<String,StoreDTO> map = com.gic.commons.util.CollectionUtil.toMap(storeList, "storeId");
		
		for(StoreVo vo:resultList){
			if(map.get(vo.getRelatedId())!=null){
				vo.setStoreCode(map.get(vo.getRelatedId()).getStoreCode());
				vo.setStoreId(map.get(vo.getRelatedId()).getStoreId());
				vo.setStoreName(map.get(vo.getRelatedId()).getStoreName());
			}
		}
		
		
		Page resultPage = new Page<>(); 
		resultPage.setCurrentPage(page.getCurrentPage());
		resultPage.setPageSize(page.getPageSize());
		resultPage.setTotalCount(page.getTotalCount());
		resultPage.setResult(resultList);
		return resultResponse(HaoBanErrCode.ERR_1,resultPage);
		
	}

}
