package com.gic.haoban.manage.web.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.hutool.core.collection.CollectionUtil;

import com.alibaba.csp.sentinel.util.StringUtil;
import com.alibaba.fastjson.JSONObject;
import com.gic.clerk.api.dto.ClerkDTO;
import com.gic.clerk.api.service.ClerkService;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.service.StoreService;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.dto.StaffDTO;
import com.gic.haoban.manage.api.dto.StaffDepartmentRelatedDTO;
import com.gic.haoban.manage.api.service.BindApiService;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.api.service.StaffApiService;
import com.gic.haoban.manage.api.service.StaffDepartmentRelatedApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.interceptor.WebInterceptor;
import com.gic.haoban.manage.web.vo.ClerkVo;
import com.gic.haoban.manage.web.vo.StoreVO;

@RestController
public class ClerkController extends WebBaseController{
    private static Logger logger= LoggerFactory.getLogger(WebInterceptor.class);

	@Autowired
	private ClerkService clerkService;
	@Autowired
	private StaffApiService staffApiService;
	@Autowired
	private StaffDepartmentRelatedApiService staffDepartmentRelatedApiService;
	@Autowired
	private StoreService storeService;
	@Autowired
	private DepartmentApiService departmentApiService;
	@Autowired
	private BindApiService bindApiService;
	
	//导购列表
	@RequestMapping("/clerk-list")
	public HaobanResponse clerkList(String storeId,String bindFlag,String departmentId) {
		List<StaffDepartmentRelatedDTO> list = staffDepartmentRelatedApiService.listByDepartmentId(departmentId);
		List<ClerkVo> result  = new ArrayList<ClerkVo>();
//		if(CollectionUtil.isNotEmpty(list)){
//			if("1".equals(bindFlag)){
//				List<StaffDepartmentRelatedDTO> bindList = list.stream().filter(s->s.getClerkCode() != null).collect(Collectors.toList());
//				if(CollectionUtil.isNotEmpty(bindList)){
//					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, bindList);
//				}
//			}else{
//
//				List<StaffDepartmentRelatedDTO> unBindList = list.stream().filter(s->s.getClerkCode() == null).collect(Collectors.toList());
//				if(CollectionUtil.isNotEmpty(unBindList)){
//					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, unBindList);
//				}
//			}
//		}
//		return resultResponse(HaoBanErrCode.ERR_1,result);
		if(StringUtils.isAnyBlank(storeId,bindFlag,departmentId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		//绑定的clerk
		if("1".equals(bindFlag)){
			// 调陶接口获取详情数据
			if(CollectionUtil.isNotEmpty(list)){
				List<String> clerkCodes = list.stream().filter(s->StringUtils.isNotBlank(s.getClerkCode())).map(s->s.getClerkCode()).collect(Collectors.toList());
				logger.info("clerkCodes =============>为{}",JSONObject.toJSONString(clerkCodes));
				if(CollectionUtil.isNotEmpty(clerkCodes)){
					List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, true);
					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
				}
			}
		}else{
			//未绑定的clerk
			// 调陶接口获取详情数据
			if(CollectionUtil.isNotEmpty(list)){
				List<String> clerkCodes = list.stream().filter(s->StringUtils.isNotBlank(s.getClerkCode())).map(s->s.getClerkCode()).collect(Collectors.toList());
				if(CollectionUtil.isNotEmpty(clerkCodes)){
					List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, false);
					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
				}else{
					clerkCodes.add("xxxXXXX");
					List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, false);
					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
				}
			}else{
				List<String> clerkCodes = new ArrayList();
				clerkCodes.add("xxxXXXX");
				List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, false);
				result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
			}
		}
		for(ClerkVo vo:result){
			if(StringUtils.isEmpty(vo.getNationCode())){
				vo.setNationCode("86");
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1,result);
		
	}
	//选择成员列表
	@RequestMapping("/staff-list")
	public HaobanResponse staffList(String departmentId) {
		if(StringUtils.isAnyBlank(departmentId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		List<StaffDepartmentRelatedDTO> list = staffDepartmentRelatedApiService.listByDepartmentId(departmentId);
		Map<String,StaffDepartmentRelatedDTO> relatedMap = com.gic.commons.util.CollectionUtil.toMap(list, "staffId");
		List<String> staffIds = list.stream().map(s->s.getStaffId()).collect(Collectors.toList());
		List<StaffDTO>  resultlist= staffApiService.listByIds(staffIds);
		for(StaffDTO dto :resultlist){
			if(relatedMap.get(dto.getStaffId()) != null){
				dto.setStaffDepartmentRelatedId(relatedMap.get(dto.getStaffId()).getStaffDepartmentRelatedId());
				if(org.apache.commons.lang.StringUtils.isNotBlank(relatedMap.get(dto.getStaffId()).getClerkCode())){
					dto.setBindFlag(1);
					dto.setClerkCode(relatedMap.get(dto.getStaffId()).getClerkCode());
				}else{
					dto.setBindFlag(0);
				}
			}else{
				dto.setBindFlag(0);
			}
		}
		
		//查找店长clerkType
		DepartmentDTO departmentDTO = departmentApiService.selectById(departmentId);
		String storeId = departmentDTO.getRelatedId();
		if(StringUtils.isEmpty(storeId)){
		}else{
			String storeClerkCode = "";
			StoreDTO storeDTO = storeService.getStore(storeId);
			if(storeDTO!=null){
				String clerkId = storeDTO.getClerkId();
				ClerkDTO clerkDTO = clerkService.getClerkByClerkId(clerkId);
				if(clerkDTO!=null){
					storeClerkCode = clerkDTO.getClerkCode();
				}
			}
			if(StringUtil.isNotBlank(storeClerkCode)){
				for(StaffDTO dto :resultlist){
					if(storeClerkCode.equals(dto.getClerkCode())){
						dto.setClerkType(1);
					}
				}
			}
		}
		
		logger.info("result   ClerkCode =================>{}",JSONObject.toJSONString(resultlist));
		return resultResponse(HaoBanErrCode.ERR_1,resultlist);
		
	}
	//成员绑定
	@RequestMapping("/staff-bind")
	public HaobanResponse staffBind(String departmentId,String fromClerkCode,String fromStaffDepartmentRelatedId) {
		if(StringUtils.isAnyBlank(departmentId,fromClerkCode,fromStaffDepartmentRelatedId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		bindApiService.staffBind(departmentId, fromClerkCode, fromStaffDepartmentRelatedId);
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	//成员解除绑定
	@RequestMapping("/clerk-single-unbind")
	public HaobanResponse clerkSingleUnbind(String fromClerkCode,String departmentId) {
		if(StringUtils.isAnyBlank(fromClerkCode)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		bindApiService.clerkSingleUnbind(fromClerkCode, departmentId);
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	//成员换绑定
	@RequestMapping("/clerk-unbind")
	public HaobanResponse clerkUnbind(String departmentId,String fromClerkCode,String toStaffId,String manager) {
		if(StringUtils.isAnyBlank(fromClerkCode,toStaffId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		StaffDepartmentRelatedDTO staffDepartmentRelatedDTO = staffDepartmentRelatedApiService.getOneByStaffIdAndDepartmentId(toStaffId, departmentId);
		if(staffDepartmentRelatedDTO == null){
			return resultResponse(HaoBanErrCode.ERR_400017);
		}
		bindApiService.clerkUnbind(departmentId, fromClerkCode, toStaffId, manager);
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	//店长转让
	@RequestMapping("/clerk-manager-tranfer")
	public HaobanResponse clerkManagerTranfer(String departmentId,String fromClerkCode,String toStaffDepartmentRelatedId) {
		logger.info("===========================》111111111111111");
		if(StringUtils.isAnyBlank(fromClerkCode,toStaffDepartmentRelatedId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		bindApiService.clerkManagerTranfer(departmentId, fromClerkCode, toStaffDepartmentRelatedId);
		return resultResponse(HaoBanErrCode.ERR_1);
	
	}
}
